@@ -39,7 +39,7 @@ use warnings;
 use utf8;
 use 5.008008; # minumum perl version is 5.8.8
 
-our $VERSION = '1.059_1';
+our $VERSION = '1.103_1';
 our $VERSION_MATURITY = "";
 
 use constant ONE_MB => 1024*1024;
@@ -94,11 +94,16 @@ sub print_system_modules_version
 
 sub load_all_dynamic_modules
 {
-	# we load here all dynamically loaded modules, to check that installation is correct.
 	require App::MtAws::Command::Sync;
 	require App::MtAws::Command::Retrieve;
 	require App::MtAws::Command::CheckLocalHash;
 	require App::MtAws::Command::DownloadInventory;
+}
+
+sub check_all_dynamic_modules
+{
+	# we load here all dynamically loaded modules, to check that installation is correct.
+	load_all_dynamic_modules();
 	check_module_versions;
 }
 
@@ -285,7 +290,7 @@ END
 		$options->{concurrency} = 1; # TODO implement this in ConfigEngine
 
 		with_forks 1, $options, sub {
-			my $ft = App::MtAws::QueueJob::RetrieveInventory->new();
+			my $ft = App::MtAws::QueueJob::RetrieveInventory->new(format => $options->{'request-inventory-format'});
 			my ($R) = fork_engine->{parent_worker}->process_task($ft, undef);
 		}
 	} elsif ($action eq 'download-inventory') {
@@ -338,6 +343,7 @@ Commands:
 	  --segment-size - Size for multi-segment download, in megabytes
 	check-local-hash
 	retrieve-inventory
+	  --request-inventory-format - json or csv
 	download-inventory
 	  --new-journal - Write inventory as new journal
 	create-vault VAULT-NAME
@@ -360,7 +366,7 @@ END
 ## use Test::Tabs
 
 	} elsif ($action eq 'version') {
-		load_all_dynamic_modules();
+		check_all_dynamic_modules();
 		print "mt-aws-glacier version: $VERSION $VERSION_MATURITY\n";
 		print "Perl Version: $]\n";
 		print_system_modules_version();
@@ -375,4 +381,6 @@ sub check_stdin_not_empty
 		if eof(STDIN); # we block until first byte arrive, then we put it back in to buffer
 }
 
+BEGIN { load_all_dynamic_modules() if $^C };
+
 1;
